@@ -1159,8 +1159,15 @@ class ContractEvent:
             event_name=cls.event_name)
 
     @combomethod
+    @deprecated_for('process_receipt')
     def processReceipt(
         self, txn_receipt: TxReceipt, errors: EventLogErrorFlags = WARN
+    ) -> Iterable[EventData]:
+        return self.process_receipt(txn_receipt, errors)
+
+    @combomethod
+    def process_receipt(
+        self, txn_receipt: TxReceipt, errors: EventLogErrorFlags = WARN
     ) -> Iterable[EventData]:
         return self._parse_logs(txn_receipt, errors)
 
@@ -1196,10 +1203,16 @@ class ContractEvent:
             yield rich_log
 
     @combomethod
+    @deprecated_for('process_log')
     def processLog(self, log: HexStr) -> EventData:
+        return self.process_log(log)
+
+    @combomethod
+    def process_log(self, log: HexStr) -> EventData:
         return get_event_data(self.web3.codec, self.abi, log)
 
     @combomethod
+    @deprecated_for('create_filter')
     def createFilter(
             self, *,  # PEP 3102
             argument_filters: Optional[Dict[str, Any]] = None,
@@ -1207,12 +1220,28 @@ class ContractEvent:
             toBlock: BlockIdentifier = "latest",
             address: Optional[ChecksumAddress] = None,
             topics: Optional[Sequence[Any]] = None) -> LogFilter:
+
+        return self.create_filter(
+            argument_filters=argument_filters,
+            fromBlock=fromBlock,
+            toBlock=toBlock,
+            address=address,
+            topics=topics)
+
+    @combomethod
+    def create_filter(
+            self, *,  # PEP 3102
+            argument_filters: Optional[Dict[str, Any]] = None,
+            fromBlock: Optional[BlockIdentifier] = None,
+            toBlock: BlockIdentifier = "latest",
+            address: Optional[ChecksumAddress] = None,
+            topics: Optional[Sequence[Any]] = None) -> LogFilter:
         """
         Create filter object that tracks logs emitted by this contract event.
         :param filter_params: other parameters to limit the events
         """
         if fromBlock is None:
-            raise TypeError("Missing mandatory keyword argument to createFilter: fromBlock")
+            raise TypeError("Missing mandatory keyword argument to create_filter: fromBlock")
 
         if argument_filters is None:
             argument_filters = dict()
@@ -1268,14 +1297,15 @@ class ContractEvent:
         return builder
 
     @combomethod
-    def getLogs(self,
-                argument_filters: Optional[Dict[str, Any]] = None,
-                fromBlock: Optional[BlockIdentifier] = None,
-                toBlock: Optional[BlockIdentifier] = None,
-                blockHash: Optional[HexBytes] = None) -> Iterable[EventData]:
+    def get_logs(self,
+                 argument_filters: Optional[Dict[str, Any]] = None,
+                 fromBlock: Optional[BlockIdentifier] = None,
+                 toBlock: Optional[BlockIdentifier] = None,
+                 blockHash: Optional[HexBytes] = None
+                 ) -> Iterable[EventData]:
         """Get events for this contract instance using eth_getLogs API.
 
-        This is a stateless method, as opposed to createFilter.
+        This is a stateless method, as opposed to create_filter.
         It can be safely called against nodes which do not provide
         eth_newFilter API, like Infura nodes.
 
@@ -1292,7 +1322,7 @@ class ContractEvent:
             from = max(mycontract.web3.eth.block_number - 10, 1)
             to = mycontract.web3.eth.block_number
 
-            events = mycontract.events.Transfer.getLogs(fromBlock=from, toBlock=to)
+            events = mycontract.events.Transfer.get_logs(fromBlock=from, toBlock=to)
 
             for e in events:
                 print(e["args"]["from"],
@@ -1367,6 +1397,15 @@ class ContractEvent:
         # Convert raw binary data to Python proxy objects as described by ABI
         return tuple(get_event_data(self.web3.codec, abi, entry) for entry in logs)
 
+    @combomethod
+    @deprecated_for('get_logs')
+    def getLogs(self,
+                argument_filters: Optional[Dict[str, Any]] = None,
+                fromBlock: Optional[BlockIdentifier] = None,
+                toBlock: Optional[BlockIdentifier] = None,
+                blockHash: Optional[HexBytes] = None) -> Iterable[EventData]:
+        return self.get_logs(argument_filters, fromBlock, toBlock, blockHash)
+
     @classmethod
     def factory(cls, class_name: str, **kwargs: Any) -> PropertyCheckingFactory:
         return PropertyCheckingFactory(class_name, (cls,), kwargs)
@@ -1486,13 +1525,13 @@ def check_for_forbidden_api_filter_arguments(
         _input = name_indexed_inputs[filter_name]
         if is_array_type(_input['type']):
             raise TypeError(
-                "createFilter no longer supports array type filter arguments. "
+                "create_filter no longer supports array type filter arguments. "
                 "see the build_filter method for filtering array type filters.")
         if is_list_like(filter_value) and is_dynamic_sized_type(_input['type']):
             raise TypeError(
-                "createFilter no longer supports setting filter argument options for dynamic sized "
-                "types. See the build_filter method for setting filters with the match_any "
-                "method.")
+                "create_filter no longer supports setting filter argument options for "
+                "dynamic sized types. See the build_filter method for setting filters "
+                "with the match_any method.")
 
 
 def call_contract_function(
